import * as i0 from '@angular/core';
import { Component, HostBinding, Input, ContentChildren, HostListener, EventEmitter, ViewEncapsulation, Output, ContentChild, NgModule } from '@angular/core';
import { MatAnchor, MatButton, MatButtonModule } from '@angular/material/button';
import { MatTooltip } from '@angular/material/tooltip';
import { combineLatest } from 'rxjs';

/* tslint:disable */
const Z_INDEX_ITEM = 23;
class SmdFabSpeedDialTrigger {
    constructor(injector) {
        /**
         * Whether this trigger should spin (360dg) while opening the speed dial
         */
        this.spin = false;
        this.isOpen = false;
        this.tooltipEventsSet = false;
        this._parent = injector.get(SmdFabSpeedDialComponent);
    }
    _onClick(event) {
        if (!this._parent.fixed && !this._parent.forceTooltips) {
            this._parent.toggle();
            event.stopPropagation();
        }
    }
    getAllButtons() {
        return [
            ...(this._anchors ? this._anchors.toArray() : []),
            ...(this._buttons ? this._buttons.toArray() : [])
        ];
    }
    showTooltips() {
        if (this._parent.forceTooltips && this.isOpen && this._tooltips) {
            this._tooltips.forEach((tooltip, i) => {
                tooltip.hide();
                for (let n = i * 65 + 3; n <= 1500; n += 150) {
                    setTimeout(() => {
                        if (this._parent.forceTooltips &&
                            this.isOpen &&
                            !tooltip._isTooltipVisible()) {
                            tooltip.show();
                        }
                    }, n);
                }
            });
        }
    }
    show() {
        this.isOpen = true;
        if (this._parent.forceTooltips && !this.tooltipEventsSet) {
            this.tooltipEventsSet = true;
            this.getAllButtons().forEach(button => {
                button._getHostElement().addEventListener('mouseleave', () => {
                    this.showTooltips();
                });
            });
        }
        this.showTooltips();
    }
    hide() {
        this.isOpen = false;
        if (this._parent.forceTooltips && this._tooltips) {
            this._tooltips.forEach(tooltip => {
                tooltip.hide();
            });
        }
    }
}
SmdFabSpeedDialTrigger.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialTrigger, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component });
SmdFabSpeedDialTrigger.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.0", type: SmdFabSpeedDialTrigger, selector: "smd-fab-trigger", inputs: { spin: "spin" }, host: { listeners: { "click": "_onClick($event)" }, properties: { "class.smd-spin": "this.spin" } }, queries: [{ propertyName: "_anchors", predicate: MatAnchor }, { propertyName: "_buttons", predicate: MatButton }, { propertyName: "_tooltips", predicate: MatTooltip }], ngImport: i0, template: ` <ng-content select="[mat-fab]"></ng-content> `, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialTrigger, decorators: [{
            type: Component,
            args: [{
                    selector: 'smd-fab-trigger',
                    template: ` <ng-content select="[mat-fab]"></ng-content> `
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; }, propDecorators: { spin: [{
                type: HostBinding,
                args: ['class.smd-spin']
            }, {
                type: Input
            }], _anchors: [{
                type: ContentChildren,
                args: [MatAnchor]
            }], _buttons: [{
                type: ContentChildren,
                args: [MatButton]
            }], _tooltips: [{
                type: ContentChildren,
                args: [MatTooltip]
            }], _onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });
class SmdFabSpeedDialActions {
    constructor(injector, renderer) {
        this.renderer = renderer;
        this.isOpen = false;
        this.tooltipEventsSet = false;
        this._parent = injector.get(SmdFabSpeedDialComponent);
    }
    getAllButtons() {
        return [
            ...(this._anchors ? this._anchors.toArray() : []),
            ...(this._buttons ? this._buttons.toArray() : [])
        ];
    }
    ngAfterContentInit() {
        if (!this._anchors || !this._buttons) {
            return;
        }
        combineLatest([this._anchors.changes, this._buttons.changes]).subscribe(() => {
            this.initButtonStates();
            this._parent.setActionsVisibility();
        });
        this.initButtonStates();
    }
    initButtonStates() {
        this.getAllButtons().forEach((button, i) => {
            this.renderer.addClass(button._getHostElement(), 'smd-fab-action-item');
            this.changeElementStyle(button._getHostElement(), 'z-index', '' + (Z_INDEX_ITEM - i));
        });
    }
    showTooltips() {
        if (this._parent.forceTooltips && this.isOpen && this._tooltips) {
            this._tooltips.forEach((tooltip, i) => {
                tooltip.hide();
                for (let n = i * 65 + 3; n <= 1500; n += 150) {
                    setTimeout(() => {
                        if (this._parent.forceTooltips &&
                            this.isOpen &&
                            !tooltip._isTooltipVisible()) {
                            tooltip.show();
                        }
                    }, n);
                }
            });
        }
    }
    show() {
        this.isOpen = true;
        this.getAllButtons().forEach((button, i) => {
            let transitionDelay = 0;
            let transform;
            if (this._parent.animationMode == 'scale') {
                // Incremental transition delay of 65ms for each action button
                transitionDelay = 3 + 65 * i;
                transform = 'scale(1)';
            }
            else {
                transform = this.getTranslateFunction('0');
            }
            this.changeElementStyle(button._getHostElement(), 'transition-delay', transitionDelay + 'ms');
            this.changeElementStyle(button._getHostElement(), 'opacity', '1');
            this.changeElementStyle(button._getHostElement(), 'transform', transform);
            if (this._parent.forceTooltips && !this.tooltipEventsSet) {
                button._getHostElement().addEventListener('mouseleave', () => {
                    this.showTooltips();
                });
            }
        });
        if (this._parent.forceTooltips) {
            this.tooltipEventsSet = true;
        }
        this.showTooltips();
    }
    hide() {
        this.isOpen = false;
        this.getAllButtons().forEach((button, i) => {
            let opacity = '1';
            let transitionDelay = 0;
            let transform;
            if (this._parent.animationMode == 'scale') {
                transitionDelay = 3 - 65 * i;
                transform = 'scale(0)';
                opacity = '0';
            }
            else {
                transform = this.getTranslateFunction(55 * (i + 1) - i * 5 + 'px');
            }
            this.changeElementStyle(button._getHostElement(), 'transition-delay', transitionDelay + 'ms');
            this.changeElementStyle(button._getHostElement(), 'opacity', opacity);
            this.changeElementStyle(button._getHostElement(), 'transform', transform);
        });
        if (this._parent.forceTooltips && this._tooltips) {
            this._tooltips.forEach(tooltip => {
                tooltip.hide();
            });
        }
    }
    getTranslateFunction(value) {
        let dir = this._parent.direction;
        let translateFn = dir == 'up' || dir == 'down' ? 'translateY' : 'translateX';
        let sign = dir == 'down' || dir == 'right' ? '-' : '';
        return translateFn + '(' + sign + value + ')';
    }
    changeElementStyle(elem, style, value) {
        // FIXME - Find a way to create a "wrapper" around the action button(s) provided by the user, so we don't change it's style tag
        if (value) {
            this.renderer.setStyle(elem, style, value);
        }
        else {
            this.renderer.removeStyle(elem, style);
        }
    }
}
SmdFabSpeedDialActions.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialActions, deps: [{ token: i0.Injector }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
SmdFabSpeedDialActions.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.0", type: SmdFabSpeedDialActions, selector: "smd-fab-actions", queries: [{ propertyName: "_anchors", predicate: MatAnchor }, { propertyName: "_buttons", predicate: MatButton }, { propertyName: "_tooltips", predicate: MatTooltip }], ngImport: i0, template: ` <ng-content select="[mat-mini-fab]"></ng-content> `, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialActions, decorators: [{
            type: Component,
            args: [{
                    selector: 'smd-fab-actions',
                    template: ` <ng-content select="[mat-mini-fab]"></ng-content> `
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i0.Renderer2 }]; }, propDecorators: { _anchors: [{
                type: ContentChildren,
                args: [MatAnchor]
            }], _buttons: [{
                type: ContentChildren,
                args: [MatButton]
            }], _tooltips: [{
                type: ContentChildren,
                args: [MatTooltip]
            }] } });
class SmdFabSpeedDialComponent {
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.isInitialized = false;
        this._direction = 'up';
        this._open = false;
        this._animationMode = 'fling';
        /**
         * Whether this speed dial is fixed on screen (user cannot change it by clicking)
         */
        this.fixed = false;
        /**
         * Whether this all tooltips should be forced open
         */
        this.forceTooltips = false;
        this.openChange = new EventEmitter();
    }
    /**
     * Whether this speed dial is opened
     */
    get open() {
        return this._open;
    }
    set open(open) {
        let previousOpen = this._open;
        this._open = open;
        if (previousOpen != this._open) {
            this.openChange.emit(this._open);
            if (this.isInitialized) {
                this.setActionsVisibility();
            }
        }
    }
    /**
     * The direction of the speed dial. Can be 'up', 'down', 'left' or 'right'
     */
    get direction() {
        return this._direction;
    }
    set direction(direction) {
        let previousDir = this._direction;
        this._direction = direction;
        if (previousDir != this.direction) {
            this._setElementClass(previousDir, false);
            this._setElementClass(this.direction, true);
            if (this.isInitialized) {
                this.setActionsVisibility();
            }
        }
    }
    /**
     * The animation mode to open the speed dial. Can be 'fling' or 'scale'
     */
    get animationMode() {
        return this._animationMode;
    }
    set animationMode(animationMode) {
        let previousAnimationMode = this._animationMode;
        this._animationMode = animationMode;
        if (previousAnimationMode != this._animationMode) {
            this._setElementClass(previousAnimationMode, false);
            this._setElementClass(this.animationMode, true);
            if (this.isInitialized) {
                // To start another detect lifecycle and force the "close" on the action buttons
                Promise.resolve(null).then(() => (this.open = false));
            }
        }
    }
    ngAfterContentInit() {
        this.isInitialized = true;
        this.setActionsVisibility();
        this._setElementClass(this.direction, true);
        this._setElementClass(this.animationMode, true);
    }
    ngOnDestroy() {
        this.forceTooltips = false;
    }
    /**
     * Toggle the open state of this speed dial
     */
    toggle() {
        this.open = !this.open;
    }
    _onClick() {
        if (!this.fixed && !this.forceTooltips && this.open) {
            this.open = false;
        }
    }
    setActionsVisibility() {
        var _a, _b, _c, _d;
        if (this.open) {
            (_a = this._childTrigger) === null || _a === void 0 ? void 0 : _a.show();
            (_b = this._childActions) === null || _b === void 0 ? void 0 : _b.show();
        }
        else {
            (_c = this._childTrigger) === null || _c === void 0 ? void 0 : _c.hide();
            (_d = this._childActions) === null || _d === void 0 ? void 0 : _d.hide();
        }
    }
    _setElementClass(elemClass, isAdd) {
        if (isAdd) {
            this.renderer.addClass(this.elementRef.nativeElement, `smd-${elemClass}`);
        }
        else {
            this.renderer.removeClass(this.elementRef.nativeElement, `smd-${elemClass}`);
        }
    }
}
SmdFabSpeedDialComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
SmdFabSpeedDialComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.0", type: SmdFabSpeedDialComponent, selector: "smd-fab-speed-dial", inputs: { fixed: "fixed", forceTooltips: "forceTooltips", open: "open", direction: "direction", animationMode: "animationMode" }, outputs: { openChange: "openChange" }, host: { listeners: { "click": "_onClick()" }, properties: { "class.smd-opened": "this.open" } }, queries: [{ propertyName: "_childActions", first: true, predicate: SmdFabSpeedDialActions, descendants: true }, { propertyName: "_childTrigger", first: true, predicate: SmdFabSpeedDialTrigger, descendants: true }], ngImport: i0, template: `
		<div class="smd-fab-speed-dial-container">
			<ng-content select="smd-fab-trigger"></ng-content>
			<ng-content select="smd-fab-actions"></ng-content>
		</div>
	`, isInline: true, styles: ["smd-fab-speed-dial{display:inline-block}smd-fab-speed-dial.smd-opened .smd-fab-speed-dial-container smd-fab-trigger.smd-spin{transform:rotate(360deg)}smd-fab-speed-dial .smd-fab-speed-dial-container{position:relative;display:flex;align-items:center;z-index:20}smd-fab-speed-dial .smd-fab-speed-dial-container smd-fab-trigger{pointer-events:auto;z-index:24}smd-fab-speed-dial .smd-fab-speed-dial-container smd-fab-trigger.smd-spin{transition:all .6s cubic-bezier(.4,0,.2,1)}smd-fab-speed-dial .smd-fab-speed-dial-container smd-fab-actions{display:flex;height:auto}smd-fab-speed-dial.smd-fling .smd-fab-speed-dial-container smd-fab-actions .smd-fab-action-item{display:block;opacity:1;transition:all .3s cubic-bezier(.55,0,.55,.2)}smd-fab-speed-dial.smd-scale .smd-fab-speed-dial-container smd-fab-actions .smd-fab-action-item{transform:scale(0);transition:all .3s cubic-bezier(.55,0,.55,.2);transition-duration:.14286s}smd-fab-speed-dial.smd-down .smd-fab-speed-dial-container{flex-direction:column}smd-fab-speed-dial.smd-down .smd-fab-speed-dial-container smd-fab-trigger{order:1}smd-fab-speed-dial.smd-down .smd-fab-speed-dial-container smd-fab-actions{flex-direction:column;order:2}smd-fab-speed-dial.smd-down .smd-fab-speed-dial-container smd-fab-actions .smd-fab-action-item{margin-top:10px}smd-fab-speed-dial.smd-up .smd-fab-speed-dial-container{flex-direction:column}smd-fab-speed-dial.smd-up .smd-fab-speed-dial-container smd-fab-trigger{order:2}smd-fab-speed-dial.smd-up .smd-fab-speed-dial-container smd-fab-actions{flex-direction:column-reverse;order:1}smd-fab-speed-dial.smd-up .smd-fab-speed-dial-container smd-fab-actions .smd-fab-action-item{margin-bottom:10px}smd-fab-speed-dial.smd-left .smd-fab-speed-dial-container{flex-direction:row}smd-fab-speed-dial.smd-left .smd-fab-speed-dial-container smd-fab-trigger{order:2}smd-fab-speed-dial.smd-left .smd-fab-speed-dial-container smd-fab-actions{flex-direction:row-reverse;order:1}smd-fab-speed-dial.smd-left .smd-fab-speed-dial-container smd-fab-actions .smd-fab-action-item{margin-right:10px}smd-fab-speed-dial.smd-right .smd-fab-speed-dial-container{flex-direction:row}smd-fab-speed-dial.smd-right .smd-fab-speed-dial-container smd-fab-trigger{order:1}smd-fab-speed-dial.smd-right .smd-fab-speed-dial-container smd-fab-actions{flex-direction:row;order:2}smd-fab-speed-dial.smd-right .smd-fab-speed-dial-container smd-fab-actions .smd-fab-action-item{margin-left:10px}\n"], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'smd-fab-speed-dial',
                    template: `
		<div class="smd-fab-speed-dial-container">
			<ng-content select="smd-fab-trigger"></ng-content>
			<ng-content select="smd-fab-actions"></ng-content>
		</div>
	`,
                    styles: [
                        `
			smd-fab-speed-dial {
				display: inline-block;
			}
			smd-fab-speed-dial.smd-opened
				.smd-fab-speed-dial-container
				smd-fab-trigger.smd-spin {
				-webkit-transform: rotate(360deg);
				transform: rotate(360deg);
			}
			smd-fab-speed-dial .smd-fab-speed-dial-container {
				position: relative;
				display: -webkit-box;
				display: -webkit-flex;
				display: flex;
				-webkit-box-align: center;
				-webkit-align-items: center;
				align-items: center;
				z-index: 20;
			}
			smd-fab-speed-dial .smd-fab-speed-dial-container smd-fab-trigger {
				pointer-events: auto;
				z-index: 24;
			}
			smd-fab-speed-dial
				.smd-fab-speed-dial-container
				smd-fab-trigger.smd-spin {
				-webkit-transition: all 0.6s cubic-bezier(0.4, 0, 0.2, 1);
				transition: all 0.6s cubic-bezier(0.4, 0, 0.2, 1);
			}
			smd-fab-speed-dial .smd-fab-speed-dial-container smd-fab-actions {
				display: -webkit-box;
				display: -webkit-flex;
				display: flex;
				height: auto;
			}
			smd-fab-speed-dial.smd-fling
				.smd-fab-speed-dial-container
				smd-fab-actions
				.smd-fab-action-item {
				display: block;
				opacity: 1;
				-webkit-transition: all 0.3s cubic-bezier(0.55, 0, 0.55, 0.2);
				transition: all 0.3s cubic-bezier(0.55, 0, 0.55, 0.2);
			}
			smd-fab-speed-dial.smd-scale
				.smd-fab-speed-dial-container
				smd-fab-actions
				.smd-fab-action-item {
				-webkit-transform: scale(0);
				transform: scale(0);
				-webkit-transition: all 0.3s cubic-bezier(0.55, 0, 0.55, 0.2);
				transition: all 0.3s cubic-bezier(0.55, 0, 0.55, 0.2);
				-webkit-transition-duration: 0.14286s;
				transition-duration: 0.14286s;
			}
			smd-fab-speed-dial.smd-down .smd-fab-speed-dial-container {
				-webkit-box-orient: vertical;
				-webkit-box-direction: normal;
				-webkit-flex-direction: column;
				flex-direction: column;
			}
			smd-fab-speed-dial.smd-down
				.smd-fab-speed-dial-container
				smd-fab-trigger {
				-webkit-box-ordinal-group: 2;
				-webkit-order: 1;
				order: 1;
			}
			smd-fab-speed-dial.smd-down
				.smd-fab-speed-dial-container
				smd-fab-actions {
				-webkit-box-orient: vertical;
				-webkit-box-direction: normal;
				-webkit-flex-direction: column;
				flex-direction: column;
				-webkit-box-ordinal-group: 3;
				-webkit-order: 2;
				order: 2;
			}
			smd-fab-speed-dial.smd-down
				.smd-fab-speed-dial-container
				smd-fab-actions
				.smd-fab-action-item {
				margin-top: 10px;
			}
			smd-fab-speed-dial.smd-up .smd-fab-speed-dial-container {
				-webkit-box-orient: vertical;
				-webkit-box-direction: normal;
				-webkit-flex-direction: column;
				flex-direction: column;
			}
			smd-fab-speed-dial.smd-up
				.smd-fab-speed-dial-container
				smd-fab-trigger {
				-webkit-box-ordinal-group: 3;
				-webkit-order: 2;
				order: 2;
			}
			smd-fab-speed-dial.smd-up
				.smd-fab-speed-dial-container
				smd-fab-actions {
				-webkit-box-orient: vertical;
				-webkit-box-direction: reverse;
				-webkit-flex-direction: column-reverse;
				flex-direction: column-reverse;
				-webkit-box-ordinal-group: 2;
				-webkit-order: 1;
				order: 1;
			}
			smd-fab-speed-dial.smd-up
				.smd-fab-speed-dial-container
				smd-fab-actions
				.smd-fab-action-item {
				margin-bottom: 10px;
			}
			smd-fab-speed-dial.smd-left .smd-fab-speed-dial-container {
				-webkit-box-orient: horizontal;
				-webkit-box-direction: normal;
				-webkit-flex-direction: row;
				flex-direction: row;
			}
			smd-fab-speed-dial.smd-left
				.smd-fab-speed-dial-container
				smd-fab-trigger {
				-webkit-box-ordinal-group: 3;
				-webkit-order: 2;
				order: 2;
			}
			smd-fab-speed-dial.smd-left
				.smd-fab-speed-dial-container
				smd-fab-actions {
				-webkit-box-orient: horizontal;
				-webkit-box-direction: normal;
				-webkit-flex-direction: row-reverse;
				flex-direction: row-reverse;
				-webkit-box-ordinal-group: 2;
				-webkit-order: 1;
				order: 1;
			}
			smd-fab-speed-dial.smd-left
				.smd-fab-speed-dial-container
				smd-fab-actions
				.smd-fab-action-item {
				margin-right: 10px;
			}
			smd-fab-speed-dial.smd-right .smd-fab-speed-dial-container {
				-webkit-box-orient: horizontal;
				-webkit-box-direction: normal;
				-webkit-flex-direction: row;
				flex-direction: row;
			}
			smd-fab-speed-dial.smd-right
				.smd-fab-speed-dial-container
				smd-fab-trigger {
				-webkit-box-ordinal-group: 2;
				-webkit-order: 1;
				order: 1;
			}
			smd-fab-speed-dial.smd-right
				.smd-fab-speed-dial-container
				smd-fab-actions {
				-webkit-box-orient: horizontal;
				-webkit-box-direction: normal;
				-webkit-flex-direction: row;
				flex-direction: row;
				-webkit-box-ordinal-group: 3;
				-webkit-order: 2;
				order: 2;
			}
			smd-fab-speed-dial.smd-right
				.smd-fab-speed-dial-container
				smd-fab-actions
				.smd-fab-action-item {
				margin-left: 10px;
			}
		`
                    ],
                    encapsulation: ViewEncapsulation.None
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { fixed: [{
                type: Input
            }], forceTooltips: [{
                type: Input
            }], open: [{
                type: HostBinding,
                args: ['class.smd-opened']
            }, {
                type: Input
            }], direction: [{
                type: Input
            }], animationMode: [{
                type: Input
            }], openChange: [{
                type: Output
            }], _childActions: [{
                type: ContentChild,
                args: [SmdFabSpeedDialActions]
            }], _childTrigger: [{
                type: ContentChild,
                args: [SmdFabSpeedDialTrigger]
            }], _onClick: [{
                type: HostListener,
                args: ['click']
            }] } });

/* tslint:disable */
/** Speed dial module. */
class SmdFabSpeedDialModule {
}
SmdFabSpeedDialModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SmdFabSpeedDialModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialModule, declarations: [SmdFabSpeedDialActions,
        SmdFabSpeedDialComponent,
        SmdFabSpeedDialTrigger], imports: [MatButtonModule], exports: [SmdFabSpeedDialActions,
        SmdFabSpeedDialComponent,
        SmdFabSpeedDialTrigger] });
SmdFabSpeedDialModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialModule, imports: [[MatButtonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.0", ngImport: i0, type: SmdFabSpeedDialModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        SmdFabSpeedDialActions,
                        SmdFabSpeedDialComponent,
                        SmdFabSpeedDialTrigger
                    ],
                    exports: [
                        SmdFabSpeedDialActions,
                        SmdFabSpeedDialComponent,
                        SmdFabSpeedDialTrigger
                    ],
                    imports: [MatButtonModule]
                }]
        }] });

/*
 * Public API Surface of angular-speed-dial
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SmdFabSpeedDialActions, SmdFabSpeedDialComponent, SmdFabSpeedDialModule, SmdFabSpeedDialTrigger };
//# sourceMappingURL=angular-speed-dial.mjs.map
